/**
 * @(#)JavaCGIBridgeStillProcessingException.java 2.00 07/18/98
 *
 * Copyright Info: This class was written by Gunther Birznieks
 * gunther@clark.net having been inspired by countless other
 * software developers.
 *
 * Version 1.00: 08/10/97
 * Version 2.00: 07/19/98
 *
 * The second version of this software was written for
 * independent study under the guidance of Professor
 * Marty Hall as part of the Johns Hopkins University
 * Computer Science Master's Degree program.
 *
 * Feel free to copy, cite, reference, sample, borrow, resell
 * or plagiarize the contents.  However, if you don't mind,
 * please let me know where it goes so that I can at least
 * watch and take part in the development of the memes. Information
 * wants to be free; support public domain freeware.  
 * 
 * Donations are appreciated.  If you use this software please
 * consider making a donation to the Electronic Frontier Foundation
 * http://www.eff.org/ or another organization of your choice
 * dedicated to defending liberty on the net.
 *
 */

package com.extropia.net;

/**
 * Signals that the user is trying to use this class when it
 * is still processing some request.
 * <P> 
 * It is important to keep in mind that although an operation
 * on JavaCGIBridge may not involve return feedback such as
 * callOneWay(), the JavaCGIBridge object must still spend time
 * in its own thread setting up an HTTP request and response.
 * <P>
 * Therefore, if you use asynchronous operations such as 
 * callOneWay() instead of synchronous operations like
 * getRawData() and getParsedData(), then you should use
 * the getStatus() method before using the object for a subsequent
 * HTTP request.  
 * <P>
 * If you feel this is too much overhead, then you are encouraged
 * to use the JavaCGIBridgePool class which keeps track of
 * which objects are free and which are not and knows when it 
 * needs to create a new one automatically.
 *
 * @version     2.00, 18 Jul 1998
 * @author      Gunther Birznieks
 * @author      Marty Hall
 *
 */

public class JavaCGIBridgeStillProcessingException extends RuntimeException {
    /**
     * Constructs a JavaCGIBridgeStillProcessingException with no detail message.
     * A detail message is a String that describes this particular
     * exception.
     */
     public JavaCGIBridgeStillProcessingException() {
         super();
     }

    /**
     * Constructs a JavaCGIBridgeStillProcessingException with the specified
     * detail message. A detail message is a String that describes
     * this particular exception.
     * @param s the String that contains a detailed message
     */
     public JavaCGIBridgeStillProcessingException(String s) {
         super(s);
     }
}

