/*
 * @(#)JavaCGIBridgeTimeOutException.java 2.00 07/18/98
 *
 * Copyright Info: This class was written by Gunther Birznieks
 * gunther@clark.net having been inspired by countless other
 * software developers.
 *
 * Version 1.00: 08/10/97
 * Version 2.00: 07/19/98
 *
 * The second version of this software was written for
 * independent study under the guidance of Professor
 * Marty Hall as part of the Johns Hopkins University
 * Computer Science Master's Degree program.
 *
 * Feel free to copy, cite, reference, sample, borrow, resell
 * or plagiarize the contents.  However, if you don't mind,
 * please let me know where it goes so that I can at least
 * watch and take part in the development of the memes. Information
 * wants to be free; support public domain freeware.
 * 
 * Donations are appreciated.  If you use this software please
 * consider making a donation to the Electronic Frontier Foundation
 * http://www.eff.org/ or another organization of your choice
 * dedicated to defending liberty on the net.
 *
 */

package com.extropia.net;

/**
 * Signals that the JavaCGIBridge Timed out while attempting to POST
 * or GET data from a URL connection.
 * <P>
 * The timeout occurs if no data has been sent to the user of
 * the JavaCGIBridge class in a specified period of time.
 * <P>
 * For getRawData or getParsedData usage of JavaCGIBridge, the
 * timeout will be sent for the time it takes for the entire 
 * HTTP request and response transactions to take place.
 * <P>
 * If an observer interface is used to look at the data while
 * the response is in progress, then the timer gets reset between
 * observer notifications.
 * <P>
 * You should keep this in mind when setting up timeouts. For example,
 * a 100,000 record result set might take 5 minutes to be 
 * received and parsed by the JavaCGIBridge class.  However, if you
 * set up an observer interface to get notified every 100 records,
 * then the timeout time limit can be set to a smaller threshold.
 *
 * @version     2.00, 18 Jul 1998
 * @author      Gunther Birznieks
 * @author      Marty Hall
 *
 */

public class JavaCGIBridgeTimeOutException extends Exception {
    /**
     * Constructs a JavaCGIBridgeTimeOutException with no detail message.
     * A detail message is a String that describes this particular
     * exception.
     */
     public JavaCGIBridgeTimeOutException() {
         super();
     }

    /**
     * Constructs a JavaCGIBridgeTimeOutException with the specified
     * detail message. A detail message is a String that describes
     * this particular exception.
     * @param s the String that contains a detailed message
     */

     public JavaCGIBridgeTimeOutException(String s) {
         super(s);
     }
}

